Learn R Programming

PWFSLSmoke (version 1.0.7)

WRCC: WRCC Monitor Names and Station IDs

Description

The WRCC http://www.wrcc.dri.edu/cgi-bin/smoke.plFire Cache Smoke Monitor Archive provides access to a variety of monitors that can be accessed with the wrcc_createMonitorObject function. Use of this funciton requires a valid stationID. The WRCC object is a list of three named vectors, each containing the stationIDs and associated names for one of the categories of monitors available at WRCC:

  • cache

  • miscellaneous

  • usfs_regional

Arguments

Format

A list with three elements

Details

WRCC monitor names and stationIDs